@@ -10,13 +10,13 @@ use Moose::Role;
 no warnings 'experimental';
 use Path::Tiny 0.108;
 
-our $VERSION='1.07';
+our $VERSION='1.08';
 
 =head1 NAME
 
 Vote::Count::Log
 
-=head1 VERSION 1.07
+=head1 VERSION 1.08
 
 =cut
 
@@ -50,6 +50,14 @@ Write the logs appending '.brief', '.full', and '.debug' for the three logs wher
 
 When logging from your methods, use logt for events that produce a summary, use logv for events that should be in the full transcript such as round counts, and finally debug is for events that may be helpful in debugging but which should not be in the transcript. Events written to logt will be included in the verbose log and all events in the verbose log will be in the debug log. 
 
+=head1 Debug Flag
+
+When the debug flag is logx methods will also emit the event as a warning (STDERR). The Debug Flag defaults to off (0), but can be explicitly set via the new method of a Vote::Count object, or toggled by passing 0 or 1 via the Debug Method.
+
+  $Election->Debug(1); # turn debug on
+  is( $Election->Action(), $expected, 'Thing Im debugging'); 
+  $Election->Debug(0); # turn debug off
+
 =cut
 
 has 'LogTo' => (
@@ -71,6 +79,12 @@ has 'LogBaseName' => (
   default => 'votecount'
 );
 
+has 'Debug' => (
+  default => 0,
+  is => 'rw',
+  isa => 'Bool',
+  );
+
 sub _logsetup ( $self ) {
   my $pathBase = $self->{'LogPath'} || '/tmp';
   $pathBase =~ s/\/$|\\$//;    # trim \ or / from end.
@@ -107,6 +121,7 @@ sub logd {
   # unshift @args, localtime->date . ' ' . localtime->time;
   my $msg = join( "\n", @args ) . "\n";
   $self->{'LogD'} .= $msg;
+  warn $msg if $self->Debug();
 }
 
 sub WriteLog {
